==> kubernetes-model-admissionregistration-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TokenReviewSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.authentication.TokenReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authentication.TokenReviewSpecFluent<A>{
  public TokenReviewSpecFluentImpl() {
  }
  public TokenReviewSpecFluentImpl(io.fabric8.kubernetes.api.model.authentication.TokenReviewSpec instance) {
    this.withAudiences(instance.getAudiences()); 
    this.withToken(instance.getToken()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> audiences = new java.util.ArrayList<java.lang.String>();
  private java.lang.String token;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAudiences(java.lang.Integer index,java.lang.String item) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    this.audiences.add(index, item);
    return (A)this;
  }
  public A setToAudiences(java.lang.Integer index,java.lang.String item) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    this.audiences.set(index, item); return (A)this;
  }
  public A addToAudiences(java.lang.String... items) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.audiences.add(item);} return (A)this;
  }
  public A addAllToAudiences(java.util.Collection<java.lang.String> items) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.audiences.add(item);} return (A)this;
  }
  public A removeFromAudiences(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
  }
  public A removeAllFromAudiences(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAudiences() {
    return this.audiences;
  }
  public java.lang.String getAudience(java.lang.Integer index) {
    return this.audiences.get(index);
  }
  public java.lang.String getFirstAudience() {
    return this.audiences.get(0);
  }
  public java.lang.String getLastAudience() {
    return this.audiences.get(audiences.size() - 1);
  }
  public java.lang.String getMatchingAudience(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: audiences) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAudience(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: audiences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAudiences(java.util.List<java.lang.String> audiences) {
    if (audiences != null) {this.audiences = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : audiences){this.addToAudiences(item);}} else { this.audiences = null;} return (A) this;
  }
  public A withAudiences(java.lang.String... audiences) {
    if (this.audiences != null) {this.audiences.clear();}
    if (audiences != null) {for (java.lang.String item :audiences){ this.addToAudiences(item);}} return (A) this;
  }
  public java.lang.Boolean hasAudiences() {
    return audiences != null && !audiences.isEmpty();
  }
  public A addNewAudience(java.lang.String arg0) {
    return (A)addToAudiences(new String(arg0));
  }
  public java.lang.String getToken() {
    return this.token;
  }
  public A withToken(java.lang.String token) {
    this.token=token; return (A) this;
  }
  public java.lang.Boolean hasToken() {
    return this.token != null;
  }
  
  /**
   * Method is deprecated. use withToken instead.
   */
  @java.lang.Deprecated
  public A withNewToken(java.lang.String arg0) {
    return (A)withToken(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TokenReviewSpecFluentImpl that = (TokenReviewSpecFluentImpl) o;
    if (audiences != null ? !audiences.equals(that.audiences) :that.audiences != null) return false;
    if (token != null ? !token.equals(that.token) :that.token != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(audiences,  token,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authentication/TokenReviewSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authentication;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class TokenReviewSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.authentication.TokenReviewSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.authentication.TokenReviewSpecFluent<A>{
  public TokenReviewSpecFluentImpl() {
  }
  public TokenReviewSpecFluentImpl(io.fabric8.kubernetes.api.model.authentication.TokenReviewSpec instance) {
    this.withAudiences(instance.getAudiences()); 
    this.withToken(instance.getToken()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> audiences = new java.util.ArrayList<java.lang.String>();
  private java.lang.String token;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToAudiences(java.lang.Integer index,java.lang.String item) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    this.audiences.add(index, item);
    return (A)this;
  }
  public A setToAudiences(java.lang.Integer index,java.lang.String item) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    this.audiences.set(index, item); return (A)this;
  }
  public A addToAudiences(java.lang.String... items) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.audiences.add(item);} return (A)this;
  }
  public A addAllToAudiences(java.util.Collection<java.lang.String> items) {
    if (this.audiences == null) {this.audiences = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.audiences.add(item);} return (A)this;
  }
  public A removeFromAudiences(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
  }
  public A removeAllFromAudiences(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.audiences!= null){ this.audiences.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getAudiences() {
    return this.audiences;
  }
  public java.lang.String getAudience(java.lang.Integer index) {
    return this.audiences.get(index);
  }
  public java.lang.String getFirstAudience() {
    return this.audiences.get(0);
  }
  public java.lang.String getLastAudience() {
    return this.audiences.get(audiences.size() - 1);
  }
  public java.lang.String getMatchingAudience(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: audiences) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingAudience(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: audiences) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAudiences(java.util.List<java.lang.String> audiences) {
    if (audiences != null) {this.audiences = new java.util.ArrayList(); for (java.lang.String item : audiences){this.addToAudiences(item);}} else { this.audiences = null;} return (A) this;
  }
  public A withAudiences(java.lang.String... audiences) {
    if (this.audiences != null) {this.audiences.clear();}
    if (audiences != null) {for (java.lang.String item :audiences){ this.addToAudiences(item);}} return (A) this;
  }
  public java.lang.Boolean hasAudiences() {
    return audiences != null && !audiences.isEmpty();
  }
  public A addNewAudience(java.lang.String arg0) {
    return (A)addToAudiences(new String(arg0));
  }
  public java.lang.String getToken() {
    return this.token;
  }
  public A withToken(java.lang.String token) {
    this.token=token; return (A) this;
  }
  public java.lang.Boolean hasToken() {
    return this.token != null;
  }
  
  /**
   * Method is deprecated. use withToken instead.
   */
  @java.lang.Deprecated
  public A withNewToken(java.lang.String arg0) {
    return (A)withToken(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TokenReviewSpecFluentImpl that = (TokenReviewSpecFluentImpl) o;
    if (audiences != null ? !audiences.equals(that.audiences) :that.audiences != null) return false;
    if (token != null ? !token.equals(that.token) :that.token != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(audiences,  token,  additionalProperties,  super.hashCode());
  }
  
}
